@@ -1,13 +1,13 @@
 package Net::DNS::RR::NSEC3PARAM;
 
 #
-# $Id: NSEC3PARAM.pm 1390 2015-09-11 11:42:11Z willem $
+# $Id: NSEC3PARAM.pm 1597 2017-09-22 08:04:02Z willem $
 #
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1390 $)[1];
+our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
 
 
 use strict;
+use warnings;
 use base qw(Net::DNS::RR);
 
 =head1 NAME
@@ -19,6 +19,8 @@ Net::DNS::RR::NSEC3PARAM - DNS NSEC3PARAM resource record
 
 use integer;
 
+use Carp;
+
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
@@ -32,7 +34,6 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless defined $self->{algorithm};
 	my $salt = $self->saltbin;
 	pack 'CCnCa*', @{$self}{qw(algorithm flags iterations)}, length($salt), $salt;
 }
@@ -41,7 +42,6 @@ sub _encode_rdata {			## encode rdata as wire-format octet string
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless defined $self->{algorithm};
 	join ' ', $self->algorithm, $self->flags, $self->iterations, $self->salt || '-';
 }
 
@@ -83,9 +83,8 @@ sub iterations {
 
 sub salt {
 	my $self = shift;
-
-	$self->saltbin( pack "H*", map { die "!hex!" if m/[^0-9A-Fa-f]/; $_ } join "", @_ ) if scalar @_;
-	unpack "H*", $self->saltbin() if defined wantarray;
+	return unpack "H*", $self->saltbin() unless scalar @_;
+	$self->saltbin( pack "H*", map /[^\dA-F]/i ? croak "corrupt hex" : $_, join "", @_ );
 }
 
 
